@@ -58,18 +58,25 @@ class Relationship(Protocol):
     """Name for 'connection-invitation' control message"""
     OUT_OF_BAND_INVITATION = 'out-of-band-invitation'
     """Name for 'out-of-band-invitation' control message"""
+    SMS_CONNECTION_INVITATION = 'sms-connection-invitation'
+    """Name for 'sms-connection-invitation' control message"""
+    SMS_OUT_OF_BAND_INVITATION = 'sms-out-of-band-invitation'
+    """Name for 'sms-out-of-band-invitation' control message"""
 
     def __init__(self,
                  for_relationship: str = None,
                  thread_id: str = None,
                  label: str = None,
-                 logo_url: str = None):
+                 logo_url: str = None,
+                 phone_number: str = None
+                 ):
         """
         Args:
             for_relationship (str): the relationship identifier (DID) for the pairwise relationship that will be used
             thread_id (str): the thread id of the already started protocol
             label (str): he label presented in the invitation to connect to this relationship
             logo_url (str): logo url presented in invitation
+            phone_number (str): Mobile phone number in international format, eg. +18011234567
         """
         super().__init__(
             self.MSG_FAMILY,
@@ -79,11 +86,9 @@ class Relationship(Protocol):
         )
 
         self.for_relationship = for_relationship
-        if label:
-            self.label = label
-        else:
-            self.label = ''
+        self.label = label
         self.logo_url = logo_url
+        self.phone_number = phone_number
 
     async def create(self, context):
         """
@@ -106,9 +111,12 @@ class Relationship(Protocol):
         """
         msg = self._get_base_message(self.CREATE)
         self._add_thread(msg)
-        msg['label'] = self.label
+        if self.label:
+            msg['label'] = self.label
         if self.logo_url:
             msg['logoUrl'] = self.logo_url
+        if self.phone_number:
+            msg['phoneNumber'] = self.phone_number
 
         return msg
 
@@ -163,6 +171,40 @@ class Relationship(Protocol):
         """
         return await self.get_message_bytes(context, self.connection_invitation_msg(context, short_invite))
 
+    async def sms_connection_invitation(self, context: Context):
+        """
+        Ask for SMS aries invitation from the verity-application agent for the relationship created by this protocol
+
+        Args:
+            context (Context): an instance of the Context object initialized to a verity-application agent
+        """
+        await self.send_message(context, await self.sms_connection_invitation_msg_packed(context))
+
+    def sms_connection_invitation_msg(self, context: Context):
+        """
+        Creates the control message without packaging and sending it.
+
+        Args:
+            context (Context): an instance of the Context object initialized to a verity-application agent
+        Return:
+            the constructed message (dict object)
+        """
+        msg = self._get_base_message(self.SMS_CONNECTION_INVITATION)
+        self._add_thread(msg)
+        self._add_relationship(msg, self.for_relationship)
+        return msg
+
+    async def sms_connection_invitation_msg_packed(self, context: Context):
+        """
+        Creates and packages message without sending it.
+
+        Args:
+            context (Context): an instance of the Context object initialized to a verity-application agent
+        Return:
+            the bytes ready for transport
+        """
+        return await self.get_message_bytes(context, self.sms_connection_invitation_msg(context))
+
     async def out_of_band_invitation(self,
                                      context: Context,
                                      short_invite: bool = None,
@@ -219,3 +261,52 @@ class Relationship(Protocol):
             the bytes ready for transport
         """
         return await self.get_message_bytes(context, self.out_of_band_invitation_msg(context, short_invite, goal))
+
+    async def sms_out_of_band_invitation(self,
+                                         context: Context,
+                                         goal: GoalsList = GoalsList.P2P_MESSAGING):
+        """
+        Ask for SMS aries out of band invitation from the verity-application agent for the relationship
+        created by this protocol
+
+        Args:
+            context (Context): an instance of the Context object initialized to a verity-application agent
+            goal (GoalsList): the initial intended goal of the relationship (this goal is expressed in the invite)
+        """
+        await self.send_message(context, await self.sms_out_of_band_invitation_msg_packed(context, goal))
+
+    def sms_out_of_band_invitation_msg(self,
+                                       context: Context,
+                                       goal: GoalsList = GoalsList.P2P_MESSAGING):
+        """
+        Creates the control message without packaging and sending it.
+
+        Args:
+            context (Context): an instance of the Context object initialized to a verity-application agent
+            goal (GoalsList): the initial intended goal of the relationship (this goal is expressed in the invite)
+        Return:
+            the constructed message (dict object)
+        """
+        msg = self._get_base_message(self.SMS_OUT_OF_BAND_INVITATION)
+        self._add_thread(msg)
+        self._add_relationship(msg, self.for_relationship)
+
+        if goal:
+            msg['goalCode'] = goal.value.code
+            msg['goal'] = goal.value.name
+
+        return msg
+
+    async def sms_out_of_band_invitation_msg_packed(self,
+                                                    context: Context,
+                                                    goal: GoalsList = GoalsList.P2P_MESSAGING):
+        """
+        Creates and packages message without sending it.
+
+        Args:
+            context (Context): an instance of the Context object initialized to a verity-application agent
+            goal (GoalsList): the initial intended goal of the relationship (this goal is expressed in the invite)
+        Return:
+            the bytes ready for transport
+        """
+        return await self.get_message_bytes(context, self.sms_out_of_band_invitation_msg(context, goal))
